# Generated by roxygen2: do not edit by hand

S3method(coef,metahunt_weight_model)
S3method(plot,metahunt)
S3method(plot,metahunt_conformal)
S3method(predict,metahunt)
S3method(predict,metahunt_weight_model)
S3method(print,dfspa)
S3method(print,metahunt)
S3method(print,metahunt_conformal)
S3method(print,metahunt_denoising_search)
S3method(print,metahunt_weight_model)
S3method(print,minmax_regret)
S3method(print,summary.metahunt)
S3method(print,summary.metahunt_conformal)
S3method(summary,metahunt)
S3method(summary,metahunt_conformal)
export(apply_wrapper)
export(build_grid)
export(conformal_from_fit)
export(coverage)
export(cross_conformal)
export(cv_error_curve)
export(dfspa)
export(f_hat_from_models)
export(fit_weight_model)
export(metahunt)
export(minmax_regret)
export(predict_target)
export(project_to_simplex)
export(reconstruction_error_curve)
export(select_denoising_params)
export(split_conformal)
