% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metahunt.R
\name{print.summary.metahunt}
\alias{print.summary.metahunt}
\title{Print a \code{summary.metahunt} object}
\usage{
\method{print}{summary.metahunt}(x, ...)
}
\arguments{
\item{x}{A \code{"summary.metahunt"} object from \code{\link[=summary.metahunt]{summary.metahunt()}}.}

\item{...}{Ignored.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print a \code{summary.metahunt} object
}
\examples{
set.seed(1)
G <- 25; m <- 40
x_grid <- seq(0, 1, length.out = G)
basis <- rbind(sin(pi * x_grid), cos(pi * x_grid), x_grid)
W <- data.frame(w1 = rnorm(m), w2 = rnorm(m))
eta <- as.matrix(W) \%*\% cbind(c(1, -0.8), c(-0.5, 1.2), c(0, 0))
pi_true <- exp(eta) / rowSums(exp(eta))
F_hat <- pi_true \%*\% basis + matrix(rnorm(m * G, sd = 0.05), m, G)

fit <- metahunt(F_hat, W, K = 3, dfspa_args = list(denoise = FALSE))
print(summary(fit))

}
