% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/select_denoising_params.R
\name{print.metahunt_denoising_search}
\alias{print.metahunt_denoising_search}
\title{Print method for d-fSPA denoising parameter search results}
\usage{
\method{print}{metahunt_denoising_search}(x, ...)
}
\arguments{
\item{x}{An object of class \code{metahunt_denoising_search} returned by
\code{\link[=select_denoising_params]{select_denoising_params()}}.}

\item{...}{Unused; present for S3 generic compatibility.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print method for d-fSPA denoising parameter search results
}
